==========================================
Grammaticomastix : insert and update chunks of text
==========================================
Grammaticomastix by suizokukan (suizokukan AT orange DOT fr)

Note : this Python3 project can't be used with python2.

project's purpose
=================

Grammaticomastix...

installation
============
$pip3 install grammaticomastix

name
====
Grammaticomastix : the whip of the grammar

more
====
see README.md file.
see https://github.com/suizokukan/grammaticomastix
